@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-__author__ = '陈章'
-__date__ = '2019/11/6 11:30'
+__author__ = "陈章"
+__date__ = "2019/11/6 11:30"
 
 import logging
 
@@ -10,10 +10,11 @@ logger = logging.getLogger("python_common_tools")
 
 
 class RedisQueue(object):
-
     def __init__(self, key, host="localhost", port="6379"):
         if not hasattr(RedisQueue, "pool"):
-            RedisQueue.pool = redis.ConnectionPool(host=host, port=port, decode_responses=True)
+            RedisQueue.pool = redis.ConnectionPool(
+                host=host, port=port, decode_responses=True
+            )
         self.__db = redis.Redis(connection_pool=RedisQueue.pool)
         self.key = key
 
